JarFieldConfig<T> class

Constructors

JarFieldConfig({required JarSchema<T, JarSchema<T, dynamic>> schema, T? defaultValue, bool disabled = false, List<AsyncValidator> asyncValidators = const []})
const

Properties

asyncValidators List<AsyncValidator>
final
defaultValue → T?
final
disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schema → JarSchema<T, JarSchema<T, dynamic>>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited