JarFieldState<T> class

Constructors

JarFieldState({T? value, String? error, bool isDirty = false, bool isTouched = false, bool isValidating = false, bool isDisabled = false, required String name, required void onChange(T?), required void markAsTouched()})
const

Properties

error String?
final
hashCode int
The hash code for this object.
no setterinherited
isDirty bool
final
isDisabled bool
final
isTouched bool
final
isValidating bool
final
markAsTouched → void Function()
final
name String
final
onChange → void Function(T?)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T?
final

Methods

copyWith({Object? value = const Undefined(), String? error, bool? isDirty, bool? isTouched, bool? isValidating, bool? isDisabled}) JarFieldState<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited