JarFormController class
- Inheritance
-
- Object
- ChangeNotifier
- JarFormController
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isDirty → bool
-
no setter
- isSubmitting → bool
-
no setter
- isTouched → bool
-
no setter
- isValid → bool
-
no setter
- isValidating → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
clear(
String name) → void -
clearAll(
) → void -
disable(
String name) → void -
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
override
-
enable(
String name) → void -
getErrors(
) → Map< String, String?> -
getFieldState<
T> (String name) → JarFieldState< T> ? -
getFieldStream<
T> (String name) → Stream< JarFieldState< ?T> > -
getFieldValue<
T> (String name) → T? -
getValues(
) → Map< String, dynamic> -
isRegistered(
String name) → bool -
markAsTouched(
String name) → void -
markAsUntouched(
String name) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
register<
T> (String name, JarFieldConfig< T> config) → void -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
reset(
String name) → void -
resetAll(
) → void -
setFormSubmitCallback(
Future< void> callback(Map<String, dynamic> values)?) → void -
setValue<
T> (String name, T? value) → Future< void> -
submit(
[Future< void> onSubmit(Map<String, dynamic> values)?]) → Future<bool> -
toString(
) → String -
A string representation of this object.
inherited
-
trigger(
[dynamic fields]) → void -
unwatch<
T> (String name, dynamic callback(T? value)) → void -
watch<
T> (String name, dynamic callback(T? value)) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited